api

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Overview

Package api provides a GraphQL HTTP client for the Linear API. It uses raw HTTP POST requests instead of a typed GraphQL client for simplicity and flexibility.

Index

Constants

This section is empty.

Variables

var Version = "dev"

Version is set at build time via ldflags.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client is the Linear GraphQL API client.

func NewClient

func NewClient(apiKey string) *Client

NewClient creates a new Linear API client.

func (*Client) Execute

func (c *Client) Execute(query string, variables map[string]interface{}, target interface{}) error

Execute sends a GraphQL query and unmarshals the result into the provided target. The target should be a pointer to a struct matching the "data" field of the GraphQL response.

Jump to